
# Type: negatively regulates, entity to entity




URI: [biolink:negatively_regulates_entity_to_entity](https://w3id.org/biolink/vocab/negatively_regulates_entity_to_entity)


## Domain and Range

[MolecularEntity](MolecularEntity.md) ->  <sub>0..*</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [regulates, entity to entity](regulates_entity_to_entity.md)

## Children


## Used by

 * [MolecularEntity](MolecularEntity.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Aliases:** | | activity directly negatively regulates activity of |
| **Local names:** | | negatively regulates (translator) |
|  | | activity directly negatively regulates activity of (ro) |
| **Mappings:** | | RO:0002449 |
|  | | SEMMEDDB:INHIBITS |
| **In Subsets:** | | translator_minimal |

